pub struct Event {
pub title: String,
pub text: String,
pub priority: i32,
pub hostname: String,
pub tags: Vec<String>,
pub alert_type: i32,
pub aggregation_key: String,
pub source_type_name: String,
pub timestamp: u64,
}Fields
title: Stringtext: Stringpriority: i32hostname: Stringalert_type: i32aggregation_key: Stringsource_type_name: Stringtimestamp: u64Implementations
Sourceimpl Event
impl Event
Sourcepub fn priority(&self) -> Priority
pub fn priority(&self) -> Priority
Returns the enum value of priority, or the default if the field is set to an invalid enum value.
Sourcepub fn set_priority(&mut self, value: Priority)
pub fn set_priority(&mut self, value: Priority)
Sets priority to the provided enum value.
Sourcepub fn alert_type(&self) -> AlertType
pub fn alert_type(&self) -> AlertType
Returns the enum value of alert_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_alert_type(&mut self, value: AlertType)
pub fn set_alert_type(&mut self, value: AlertType)
Sets alert_type to the provided enum value.